#ifndef _JMP_CONFIG_H
#define _JMP_CONFIG_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#if ENABLE_NLS
#  include <libintl.h>
#  include <locale.h>
#  define _(x) gettext(x)
#else
#  define _(x) (x)
#endif

#undef JMPDEBUG
#undef JMPDEBUG_MONITOR

#ifdef HAVE_JVMTI_H
 #define SUPPORT_JVMTI
#endif

/* To test WIN32 like build under Linux undef HAVE_PTHREAD_H here */
//#undef HAVE_PTHREAD_H

#ifdef HAVE_PTHREAD_H
 #define SUPPORT_PTHREAD
 /* JVM monitors or pthread mutex ? */
 #define SUPPORT_PTHREAD_HASHLOCK

 #define PTHREAD_MUTEX_DESTROY(v)		pthread_mutex_destroy(& v ## _mutex)
 #define PTHREAD_MUTEX_INIT(v, a, n, r)		*(r) = pthread_mutex_init(& v ## _mutex, a)
 #define PTHREAD_MUTEX_LOCK(v)			pthread_mutex_lock(& v ## _mutex)
 #define PTHREAD_MUTEX_UNLOCK(v)		pthread_mutex_unlock(& v ## _mutex)
 
 #define PTHREAD_MUTEXATTR_DESTROY(a)		pthread_mutexattr_destroy(a)
 #define PTHREAD_MUTEXATTR_INIT(a)		pthread_mutexattr_init(a)
 #define PTHREAD_MUTEXATTR_SETTYPE(a, t)	pthread_mutexattr_settype(a, t)

 #define PTHREAD_COND_DESTROY			pthread_cond_destroy
 #define PTHREAD_COND_INIT			pthread_cond_init
 #define PTHREAD_COND_BROADCAST			pthread_cond_broadcast
 #define PTHREAD_COND_TIMEDWAIT			pthread_cond_timedwait
#else
 #ifdef WIN32
  #define PTHREAD_MUTEX_DESTROY(v)	do {			\
		if (v ## _monitor != NULL) {			\
			jvmpi_delete_monitor (v ## _monitor);	\
			(v ## _monitor) = 0;			\
		}						\
	} while(0)
  #define PTHREAD_MUTEX_INIT(v, a, n, r)	do {			\
		JVMPI_RawMonitor _tmp_mon;				\
		_tmp_mon = jvmpi_create_monitor ((char*)n);		\
		if(_tmp_mon)						\
			*(r) = 0;					\
		else							\
			*(r) = -1;					\
		(v ## _monitor) = _tmp_mon;				\
	} while(0)
  #define PTHREAD_MUTEX_LOCK(v)		jvmpi_lock_monitor(v ## _monitor)
  #define PTHREAD_MUTEX_UNLOCK(v)	jvmpi_unlock_monitor(v ## _monitor)
  #warning "WIN32 BUILD"
 #else
  #error "Your system does not appear to have pthreads"
 #endif
#endif

#endif /* _JMP_CONFIG_H */

/* Emacs Local Variables: */
/* Emacs mode:C */
/* Emacs c-indentation-style:"gnu" */
/* Emacs c-hanging-braces-alist:((brace-list-open)(brace-entry-open)(defun-open after)(substatement-open after)(block-close . c-snug-do-while)(extern-lang-open after)) */
/* Emacs c-cleanup-list:(brace-else-brace brace-elseif-brace space-before-funcall) */
/* Emacs c-basic-offset:4 */
/* Emacs End: */
